@@ -1,8 +1,10 @@
 
 from django import forms
 from django.conf import settings
+from django.core.mail.message import EmailMessage
 from django.template import loader
-from django.core.mail import send_mail
+from django.utils.translation import ugettext_lazy as _
+
 
 class BaseEmailFormMixin(object):
     from_email = settings.DEFAULT_FROM_EMAIL
@@ -19,27 +21,43 @@ class BaseEmailFormMixin(object):
         return ''.join(subject.splitlines())
 
     def get_context(self):
+        """
+        Context sent to templates for rendering include the form's cleaned
+        data and also the current Request object.
+        """
         if not self.is_valid():
             raise ValueError("Cannot generate Context when form is invalid.")
-        return self.cleaned_data
+        return dict(request=self.request, **self.cleaned_data)
 
     def get_message_dict(self):
         return {
             "from_email": self.from_email,
-            "recipient_list": self.recipient_list,
+            "to": self.recipient_list,
             "subject": self.get_subject(),
-            "message": self.get_message(),
+            "body": self.get_message(),
         }
 
     def send_email(self, request, fail_silently=False):
         self.request = request
-        send_mail(fail_silently=fail_silently, **self.get_message_dict())
+        EmailMessage(**self.get_message_dict()).send(fail_silently=fail_silently)
+
 
 class ContactForm(forms.Form, BaseEmailFormMixin):
-    pass
+    """
+    Subclass this and declare your own fields.
+    """
+
 
 class ContactModelForm(forms.ModelForm, BaseEmailFormMixin):
     """
     You'll need to declare the model yourself.
     """
-    pass
+
+
+class BasicContactForm(ContactForm):
+    """
+    A very basic contact form you can use out of the box if you wish.
+    """
+    name = forms.CharField(label=_(u'Your name'), max_length=100)
+    email = forms.EmailField(label=_(u'Your email address'), max_length=200)
+    body = forms.CharField(label=_(u'Your message'), widget=forms.Textarea())
